import fetch from 'node-fetch';
import { AbortController } from 'abort-controller';

import { polyfillFetch } from '@mapbox/search-js-core';

/**
 * We need to mock the HTMLDocument in order to test {@link createCSSStyleSheet}.
 *
 * Bug: https://github.com/jsdom/jsdom/issues/3179
 * Reference: https://jestjs.io/docs/manual-mocks#mocking-methods-which-are-not-implemented-in-jsdom
 */
export const htmlDocFunc = jest.spyOn(
  document.implementation,
  'createHTMLDocument'
);

htmlDocFunc.mockImplementation(() => {
  return document;
});

// Needed for the 'no-scroll' package.
window.scroll = jest.fn();

/**
 * Mock ResizeObserver
 */
global.ResizeObserver = jest.fn().mockImplementation(() => ({
  observe: jest.fn(),
  unobserve: jest.fn(),
  disconnect: jest.fn()
}));

polyfillFetch({ fetch, AbortController });
